@@ -20,22 +20,15 @@ Parallel::SubFork - Manage Perl functions in forked processes.
 	foreach my $task ($manager->tasks) {
 		# Access any of the properties
 		printf "Task with PID %d resumed\n", $task->pid;
-		printf "Exist status: %d, exit code: %d\n", $task->status, $task->exit_code;
+		printf "Exist status: %d, exit code: %d\\n", $task->status, $task->exit_code;
 		printf "Args of task where: %s\n", join(', ', $task->args);
 		print "\n";
 	}
 
-or more easily:
-
-	use Parallel::SubFork qw(sub_fork);
-	
-	my $task = sub_fork(\&callback, @args);
-	$task->wait_for();
-
 =head1 DESCRIPTION
 
 This module provides a simple wrapper over the module L<Parallel::SubFork::Task>
-which in turns simplifies the usage of the system calls C<fork> and C<waitpid>.
+which in turns simplifies the usage of the system calls L<fork> and L<waitpid>.
 The idea is to isolate the tasks to be execute in functions or closures and to
 execute them in a separated process in order to take advantage of
 parallelization.
@@ -59,6 +52,10 @@ an exit code (C<0> for an execution without flaws and any other integer for
 reporting an error) and not a true value in the I<Perl> sense. The return value
 will be used as the exit code of the process that's running the task.
 
+=head1 METHODS
+
+The module defines the following methods:
+
 =cut
 
 use strict;
@@ -66,11 +63,6 @@ use warnings;
 
 use Carp;
 
-use base 'Exporter';
-our @EXPORT_OK = qw(
-	sub_fork
-);
-
 use Parallel::SubFork::Task;
 
 use base qw(Class::Accessor::Fast);
@@ -83,57 +75,7 @@ __PACKAGE__->mk_accessors(
 
 
 # Version of the module
-our $VERSION = '0.06_02';
-
-
-=head1 FUNCTIONS
-
-The module provides the following functions:
-
-=cut
-
-
-=head2 sub_fork
-
-This function provides a simple way for creating and launching tasks.
-
-Parameters:
-
-=over
-
-=item $code
-
-The code reference to execute.
-
-=item @args (optional)
-
-The arguments to pass to the code reference.
-
-=back
-
-=cut
-
-sub sub_fork {
-
-	# Arguments
-	my ($code, @args) = @_;
-
-	my $task;
-	eval {
-		$task = Parallel::SubFork::Task->start($code, @args);
-	};
-	if (my $error = $@) {
-		croak $error;
-	}
-	return $task;
-}
-
-
-=head1 METHODS
-
-The module defines the following methods:
-
-=cut
+our $VERSION = '0.01';
 
 
 =head2 new
@@ -181,17 +123,8 @@ one that created the instance object being called.
 
 Parameters:
 
-=over
-
-=item $code
-
-The code reference to execute.
-
-=item @args (optional)
-
-The arguments to pass to the code reference.
-
-=back
+	$code: the code reference to execute in a different process.
+	@args: the arguments to pass to the code reference (optional).
 
 =cut
 
@@ -302,4 +235,5 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
 at your option, any later version of Perl 5 you may have available.
 
+
 =cut
